<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="da" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Om</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Start torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Spring hashtjek over</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Opret undermappe</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Tilstand for torrent-håndtering:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Ukategoriseret</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Tilføj kategori...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Fjern kategori</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Fjern ubrugte kategorier</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Genoptag torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Sæt torrents på pause</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Slet torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Rediger kategori...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Afslut qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Kun ét link pr. linje</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Global grænse for uploadhastighed skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Global grænse for downloadhastighed skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ grænse for uploadhastighed skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ grænse for downloadhastighed skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maksimum aktive downloads skal være større end -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maksimum aktive uploads skal være større end -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maksimum aktive torrents skal være større end -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Grænsen for det maksimale antal forbindelser skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Grænsen for det maksimale antal forbindelser pr. torrent skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Grænsen for det maksimale antal uploadpladser pr. torrent skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Kan ikke gemme programpræferencer, qBittorrent er formodentligt ikke til at få kontakt med.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent på Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Grænsen for deleforhold skal være mellem 0 og 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Grænsen for seedingtid skal være mellem 0 og 525600 minutter.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Porten der bruges til indgående forbindelser skal være mellem 1 og 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Porten der bruges til webgrænsefladen skal være mellem 1 og 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Kan ikke logge ind, qBittorrent er formodentligt ikke til at få kontakt med.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Ugyldigt brugernavn eller adgangskode.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brugernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Oprindelige forfattere</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Upload torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Gem filer i:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Skriv mappe her</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mere information</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Information om certifikater</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Sæt placering</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Begræns uploadhastighed</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Begræns downloadhastighed</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Omdøb torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Andet...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Tirsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lørdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Søndag</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Download torrents fra deres URL'er eller Magnet-links</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Upload  lokal torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Er du sikker på, at du vil slette de valgte torrents fra overførselslisten?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gem</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent-klienten kan ikke kontaktes</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Global græse for antal uploadpladser skal være større end 0 eller deaktiveret.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Ugyldigt kategorinavn:\nBrug venligst ikke nogen specialtegn i kategorinavnet.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kan ikke oprette kategori</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Grænse for uploadhastighed skal være større end 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Ledig plads: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Timer for torrent inaktivitet skal være større end 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gemmehåndtering</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Grænse for downloadhastighed skal være større end 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent er blevet lukket ned</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Værktøjer</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Filer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Indstillinger...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Genoptag</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Øverste værktøjslinje</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statuslinje</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Hastighed i titellinjen</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Donér!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Genoptag alle</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Sæt på pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Sæt alle på pause</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Tilføj torrent-fil...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentation</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Tilføj torrent-link...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Global grænse for uploadhastighed</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Global grænse for downloadhastighed</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Er du sikker på, at du vil afslutte qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1/s, U: %2/s] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternative hastighedsgrænser</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Søgemotor</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrer torrentliste...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Overførsler</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top of Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Forbindelse</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighed</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Webgrænseflade</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Brugerfladens sprog:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notifikation via e-mail når download er færdig</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Kør eksternt program når torrent er færdig</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-filtrering</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Planlæg brugen af alternative grænser for hastighed</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent sat i kø</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Tilføj automatisk disse trackere til nye downloads:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Webgrænseflade (fjernstyring)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-adresse:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Serverdomæner:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Brug HTTPS i stedet for HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Tilsidesæt godkendelse for klienter på localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Tilsidesæt godkendelse for klienter i hvidlistede IP-undernet</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Opdater mit dynamiske domænenavn</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Behold ufærdige torrents i:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopiér .torrent-filer til:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopiér færdige .torrent downloads til:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Præ-allokér alle filer</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Tilføj .!qB-endelse til slutningen af ufærdige filer</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Tilføj automatisk torrents fra:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Denne server kræver en sikker forbindelse (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Godkendelse</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Adgangskode:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Aktiveret protokol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP og μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Lyttende port</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port der bruges til indgående forbindelser:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Brug UPnP/NAT-PMP port-viderestilling fra min router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Brug en anden port ved hver opstart</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Grænser for forbindelser</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maksimum antal forbindelser pr. torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Global maksimum antal forbindelser:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maksimum antal uploadpladser pr. torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Global maksimum antal uploadpladser:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy-server</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ingen)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Vært:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Brug proxy til modpartsforbindelser</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Brug kun proxy til torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filtrer sti (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuelt udelukkede IP-adresser...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Anvend på trackere</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globale grænser for hastighed</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Upload:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Download:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternative grænser for hastighed</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Fra:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Til:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Når:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Hver dag</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Hverdage</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Weekender</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Indstillinger for grænser for hastighed</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Anvend grænse for hastighed til transport-overhead</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Anvend grænse for hastighed til µTP-protokol</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privatliv</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Aktivér DHT (decentraliseret netværk) for at finde flere modparter</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Aktivér modpartsudveksling (PeX) for at finde flere modparter</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Aktivér lokal modpartsopdagelse for at finde flere modparter</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Krypteringstilstand:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Kræv kryptering</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Deaktivér kryptering</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Aktivér anonym tilstand</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maksimum aktive downloads:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maksimum aktive uploads:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maksimum aktive torrents:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Tæl ikke langsomme torrents med i disse grænser</translation>
    </message>
    <message>
        <source>then</source>
        <translation>og så</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Brug UPnP/NAT-PMP til at viderestille porten fra min router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certifikat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Nøgle:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrer</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domænenavn:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Understøttede parametre (forskel på store og små bogstaver):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentnavn</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategori</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Indholdssti (samme som rodsti til torrent med flere filer)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Rodsti (første torrent-undermappesti)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Gemmesti</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Antal filer</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrentstørrelse (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Nuværende tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Infohash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tip: Omslut parameter med citationstegn så teksten ikke bliver afkortet af blanktegn (f.eks. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Webgrænsefladens brugernavn skal være mindst 3 tegn langt.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Webgrænsefladens adgangskode skal være mindst 6 tegn langt.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Aktivér beskyttelse mod klikkidnapning</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Aktivér beskyttelse mod Cross-Site Request Forgery (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Slet .torrent-filer bagefter</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Grænse for downloadhastighed:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Grænse for uploadhastighed:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Skift nuværende adgangskode</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Brug alternativ webgrænseflade</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Standardgemmesti:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Placeringen til de alternative webbrugefladefiler må ikke være tom.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Start ikke download automatisk</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Skift torrent til manuel tilstand</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Når torrentkategori ændres:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Flyt påvirkede torrents til en anden placering</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Anvend grænse for hastighed til modparter på LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 betyder ubegrænset</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Flyt torrent til en anden placering</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Når standardgemmesti ændres:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Aktivér validering af værtsheader</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhed</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Når kategoriens gemmesti ændres:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Opret undermappe til torrents med mere end én fil</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Skift påvirkede torrents til manuel tilstand</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Filplacering:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Timer for torrent inaktivitet:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Standardtilstand for torrent-håndtering:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Når en torrent tilføjes</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>sec</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fastest upload</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allow encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resolve peer countries (GeoIP):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>min</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listen on IPv6 address (requires restart):</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flag</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Forbindelse</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Forløb</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Downloadhastighed</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Uploadhastighed</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Downloadet</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Uploadet</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Filer</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Land</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Høj</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Højeste</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not download</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackere</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Modparter</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-kilder</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Indhold</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Downloadet:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Overførsel</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tid aktiv:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>ETA:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Uploadet:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Downloadhastighed:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Uploadhastighed:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Modparter:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Downloadgrænse:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Uploadgrænse:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Spildt:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Forbindelser:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Deleforhold:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Genannoncer om:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Sidst set færdige:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Samlet størrelse:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Stykker:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Oprettet af:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Tilføjet den:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Færdig den:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Oprettet den:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent-hash:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Gemmesti:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (har %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 denne session)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maks.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 i alt)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 gns.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Downloadgrænse:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Uploadgrænse:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter files...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Overvåget mappe</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Tilsidesæt placering at gemme</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Overvåget mappe</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Standardplacering at gemme</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Brugerstatistik</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Mellemlagerstatistik</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Læsemellemlagerets træffere:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Gennemsnitlig tid i kø:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Tilsluttede modparter:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Deleforhold igennem tiden:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Download igennem tiden:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Sessionsspild:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Upload igennem tiden:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Samlet bufferstørrelse:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Ydelsesstatistik</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>I/O-jobs i kø:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Overbelastet skrivemellemlager:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Overbelastet læsemellemlager:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Samlet størrelse i kø:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 knudepunkter</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Alle (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Downloader (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seeder (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Færdige (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Genoptaget (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Sat på pause (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktive (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inaktive (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Fejlramte (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Alle (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Downloader (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seeder (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Færdige (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Sat på pause (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Genoptaget (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktive (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inaktive (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Fejlramte (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Færdig</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Modparter</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Hast. ned</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Hast. op</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Forhold</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>ETA</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Mærkater</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Tilføjet den</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Færdig den</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Downloadgrænse</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Uploadgrænse</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Downloadet</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Uploadet</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Downloadet i session</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Uploadet i session</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Tilbage</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tid aktiv</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Gemmesti</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Færdig</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Grænse for forhold</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Sidst set færdige</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Sidste aktivitet</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Samlet størrelse</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Modparter</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Meddelelse</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Downloadet</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Tracker-URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Opdaterer...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Arbejder</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiveret</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Ikke kontaktet endnu</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Arbejder ikke</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopiér tracker-URL</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Tilføj en ny tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Rediger tracker-URL...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Redigering af tracker</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leechere</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Fjern tracker</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tier</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Tilføjelse af tracker-dialog</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Liste over trackere der skal tilføjes (en pr. linje):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 siden</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Allokerer</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Sat på pause</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Færdige</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Flytter</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Seeder</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seeder</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Sat i kø</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Fejlramte</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Downloader</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Downloader metadata</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Tjekker</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Manglende filer</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Sat i kø til tjek</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Downloader</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Tjekker genoptagelsesdata</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Gået i stå</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Begrænsning af hastighed ved download af torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Begrænsning af hastighed ved upload af torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Genoptag</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Tving genoptag</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Sæt på pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Begræns deleforhold...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Begræns uploadhastighed...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Begræns downloadhastighed...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Flyt op</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Flyt ned</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Flyt til toppen</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Flyt til bunden</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Sæt placering...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Start med at downloade første og sidste stykker</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatisk torrent-håndtering</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Ny...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Nulstil</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Tving gentjek</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Super seeding-tilstand</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Omdøb...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Download i fortløbende rækkefølge</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Tving gentjek</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nyt navn</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Sæt placering</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Tving genannoncer</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Rediger kategori</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Gemmesti</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Magnet link</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queue</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Begrænsning af upload-/download-forhold for torrent</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Brug global delegrænse</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Sæt ingen delegrænse</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Sæt delegrænse til</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>forhold</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Bekræftelse for sletning</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Slet også filerne på harddisken</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Bekræft sletning - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Download fra URL'er</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Tilføj torrent-links</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 t %2 m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 d %2 t</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Ukendt</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Gemmesti er tom</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Plugin-sti:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL eller lokal mappe</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Installer plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Alle plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Søge-plugins...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Alle kategorier</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Søg i:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultater (viser</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Kun torrentnavne</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Kun aktiverede</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>ud af</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Alle steder</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Afinstaller</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Installer nyt plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Her kan du finde nye søgemotor-plugin:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Installerede søge-plugins:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiveret</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Advarsel: Sørg for at overholde dit lands love om ophavsret når du downloader torrents fra søgemotorerne.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Søg efter opdateringer</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Søge-plugins</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leechere</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Søgemotor</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seedere</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiveret</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add Peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add tag...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tag:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tag</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Untagged</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Current maintainer</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Greece</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Special Thanks</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Libraries</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Nationality:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Author</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Open description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download link</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>